/**
 * 
 */
package org.gcube.portlets.user.td.sdmximportwidget.client;

import org.gcube.portlets.user.td.gwtservice.shared.sdmx.SDMXImportSession;
import org.gcube.portlets.user.td.gwtservice.shared.tr.TabResource;
import org.gcube.portlets.user.td.wizardwidget.client.WizardCard;

import com.allen_sauer.gwt.log.client.Log;
import com.google.gwt.core.client.GWT;
import com.google.gwt.user.client.Command;
import com.google.gwt.user.client.ui.VerticalPanel;
import com.sencha.gxt.widget.core.client.FramedPanel;
import com.sencha.gxt.widget.core.client.box.AlertMessageBox;
import com.sencha.gxt.widget.core.client.button.TextButton;
import com.sencha.gxt.widget.core.client.container.VerticalLayoutContainer;
import com.sencha.gxt.widget.core.client.container.VerticalLayoutContainer.VerticalLayoutData;
import com.sencha.gxt.widget.core.client.event.HideEvent;
import com.sencha.gxt.widget.core.client.event.HideEvent.HideHandler;
import com.sencha.gxt.widget.core.client.form.FieldLabel;
import com.sencha.gxt.widget.core.client.form.FieldSet;
import com.sencha.gxt.widget.core.client.form.TextArea;
import com.sencha.gxt.widget.core.client.form.TextField;

/**
 * 
 * @author "Giancarlo Panichi" <a
 *         href="mailto:g.panichi@isti.cnr.it">g.panichi@isti.cnr.it</a>
 * 
 */
public class SDMXTableDetailCard extends WizardCard {

	protected final String TABLEDETAILPANELWIDTH = "100%";
	protected final String TABLEDETAILPANELHEIGHT = "100%";
	protected final String FORMWIDTH = "538px";

	protected SDMXImportSession importSession;
	protected SDMXTableDetailCard thisCard;

	protected static final AgenciesProperties agenciesProperties = GWT
			.create(AgenciesProperties.class);
	protected VerticalLayoutContainer p = new VerticalLayoutContainer();
	protected VerticalPanel tableDetailPanel;

	protected TextField name;
	protected TextArea description;
	protected TextArea rights;
	protected TextField agencyName;

	protected TextButton checkButton;

	// protected ComboBox<Agencies> combo=null;

	TabResource detail = new TabResource();

	public SDMXTableDetailCard(final SDMXImportSession importSession) {
		super("SDMX Table Detail", "");

		this.importSession = importSession;
		thisCard = this;

		tableDetailPanel = new VerticalPanel();

		tableDetailPanel.setSpacing(4);
		tableDetailPanel.setWidth(TABLEDETAILPANELWIDTH);
		tableDetailPanel.setHeight(TABLEDETAILPANELHEIGHT);

		FramedPanel form = new FramedPanel();
		form.setHeadingText("Details");
		form.setWidth(FORMWIDTH);

		FieldSet fieldSet = new FieldSet();
		fieldSet.setHeadingText("Information");
		fieldSet.setCollapsible(false);
		form.add(fieldSet);

		// VerticalLayoutContainer p = new VerticalLayoutContainer();
		fieldSet.add(p);

		name = new TextField();
		name.setAllowBlank(false);
		name.setEmptyText("Enter a name...");
		name.setValue(importSession.getSelectedCodelist().getName());
		p.add(new FieldLabel(name, "Name"), new VerticalLayoutData(1, -1));

		description = new TextArea();
		description.setAllowBlank(false);
		description.setEmptyText("Enter a description...");
		description.setValue(importSession.getSelectedCodelist()
				.getDescription());
		p.add(new FieldLabel(description, "Description"),
				new VerticalLayoutData(1, -1));

		rights = new TextArea();
		rights.setEmptyText("Enter rights...");
		rights.setAllowBlank(false);
		p.add(new FieldLabel(rights, "Rights"), new VerticalLayoutData(1, -1));

		agencyName = new TextField();
		agencyName.setVisible(true);
		agencyName.setEmptyText("Enter Agency...");
		agencyName.setValue(importSession.getSelectedCodelist().getAgencyId());
		FieldLabel agencyNameLabel = new FieldLabel(agencyName, "Agency");
		agencyNameLabel.setLabelSeparator("");
		p.add(agencyNameLabel, new VerticalLayoutData(1, -1));

		tableDetailPanel.add(form);

		setContent(tableDetailPanel);

	}


	@Override
	public void setup() {
		Command sayNextCard = new Command() {

			@Override
			public void execute() {
				checkData();
			}

		};

		getWizardWindow().setNextButtonCommand(sayNextCard);

		Command sayPreviousCard = new Command() {
			public void execute() {
				try {
					getWizardWindow().previousCard();
					getWizardWindow().removeCard(thisCard);
					Log.info("Remove SDMXTableDetailCard");
				} catch (Exception e) {
					Log.error("sayPreviousCard :" + e.getLocalizedMessage());
				}
			}
		};

		getWizardWindow().setPreviousButtonCommand(sayPreviousCard);
		getWizardWindow().setEnableNextButton(true);

	}

	protected void checkData() {
		getWizardWindow().setEnableNextButton(false);
		getWizardWindow().setEnableBackButton(false);
		AlertMessageBox d;
		HideHandler hideHandler = new HideHandler() {

			@Override
			public void onHide(HideEvent event) {
				getWizardWindow().setEnableNextButton(true);
				getWizardWindow().setEnableBackButton(false);

			}
		};

		if (name.getValue() == null || name.getValue().isEmpty()
				|| !name.isValid() || description.getValue() == null
				|| description.getValue().isEmpty() || !description.isValid()
				|| rights.getValue() == null || rights.getValue().isEmpty()
				|| !rights.isValid() || agencyName.getValue() == null
				|| agencyName.getValue().isEmpty() || !agencyName.isValid()) {

			d = new AlertMessageBox("Attention!", "Fill in all fields");
			d.addHideHandler(hideHandler);
			d.show();
		} else {
			name.setReadOnly(true);
			description.setReadOnly(true);
			rights.setReadOnly(true);
			agencyName.setReadOnly(true);
			goNext();
		}

	}

	protected void goNext() {
		try {
			detail.setName(name.getCurrentValue());
			detail.setAgency(agencyName.getCurrentValue());
			detail.setDescription(description.getCurrentValue());
			detail.setRight(rights.getCurrentValue());

			importSession.setTabResource(detail);
			SDMXOperationInProgressCard sdmxOperationInProgressCard = new SDMXOperationInProgressCard(
					importSession);
			getWizardWindow().addCard(sdmxOperationInProgressCard);
			Log.info("NextCard SDMXOperationInProgressCard");
			getWizardWindow().nextCard();
		} catch (Exception e) {
			Log.error("sayNextCard :" + e.getLocalizedMessage());
		}
	}

}
