/**
 * 
 */
package org.gcube.portlets.user.td.sdmximportwidget.client.progress;

import java.util.ArrayList;

import org.gcube.portlets.user.td.gwtservice.client.rpc.TDGWTServiceAsync;
import org.gcube.portlets.user.td.gwtservice.shared.sdmx.SDMXImportMonitor;
import org.gcube.portlets.user.td.widgetcommonevent.shared.TRId;

import com.allen_sauer.gwt.log.client.Log;
import com.google.gwt.user.client.Timer;
import com.google.gwt.user.client.rpc.AsyncCallback;
import com.sencha.gxt.widget.core.client.box.AlertMessageBox;
import com.sencha.gxt.widget.core.client.event.HideEvent;
import com.sencha.gxt.widget.core.client.event.HideEvent.HideHandler;

/**
 * This {@link Timer} retrieves {@link OperationProgress} from the specified
 * {@link OperationProgressSource} with the scheduled interval. The retrieved
 * information are spread to the subscribed {@link OperationProgressListener}.
 * 
 * @author "Giancarlo Panichi" <a
 *         href="mailto:g.panichi@isti.cnr.it">g.panichi@isti.cnr.it</a>
 * 
 */
public class OperationProgressUpdater extends Timer {

	protected ArrayList<OperationProgressListener> listeners = new ArrayList<OperationProgressListener>();

	/**
	 * {@inheritDoc}
	 */
	@Override
	public void run() {
		Log.debug("requesting operation progress");
		TDGWTServiceAsync.INSTANCE
				.getSDMXImportMonitor(new AsyncCallback<SDMXImportMonitor>() {

					@Override
					public void onFailure(Throwable caught) {
						cancel();
						Log.error("Error retrieving the operation state",
								caught);
						String message = getStack(caught);
						fireOperationFailed(caught,
								"Failed getting operation updates", message);
					}

					@Override
					public void onSuccess(SDMXImportMonitor result) {
						Log.info("retrieved ImportMonitor: "
								+ result.getStatus());
						switch (result.getStatus()) {
						case INITIALIZING:
							Log.info("Initializing...");
							fireOperationInitializing();
							break;
						case IN_PROGRESS:
							fireOperationUpdate(result.getProgress());
							break;
						case FAILED:
							cancel();
							errorMessage(result);
							break;
						case SUCCEDED:
							cancel();
							Log.info("Import fisnish TableId :"
									+ result.getTrId());
							fireOperationComplete(result.getTrId());
							break;
						case ABORTED:
							Log.info("Import SDMX Aborted");
							cancel();
							break;
						default:
							break;
						}

					}

				});

	}
	
	
	protected void errorMessage(SDMXImportMonitor result) {
		Log.info("SDMX Import Failed");
		Throwable th = null;
		String failure = null;
		String details = null;
		if (result.getError() != null) {
			th = result.getError();
			failure = "Failed Client Library Import";
			details = result.getError().getLocalizedMessage();
		} else {
			th = new Throwable("Failed");
			failure = "Failed Client Library Import";
			details = "Error in import";
		}
		fireOperationFailed(th, failure, details);

		AlertMessageBox d = new AlertMessageBox("Error in SDMX Import", details);
		d.addHideHandler(new HideHandler() {

			@Override
			public void onHide(HideEvent event) {
				//
			}

		});
		d.show();

	}


	protected String getStack(Throwable e) {
		String message = e.getLocalizedMessage() + " -> <br>";
		Throwable c = e.getCause();
		if (c != null)
			message += getStack(c);
		return message;
	}

	protected void fireOperationInitializing() {
		for (OperationProgressListener listener : listeners)
			listener.operationInitializing();
	}

	protected void fireOperationUpdate(float elaborated) {
		for (OperationProgressListener listener : listeners)
			listener.operationUpdate(elaborated);
	}

	protected void fireOperationComplete(TRId trId) {
		for (OperationProgressListener listener : listeners)
			listener.operationComplete(trId);
	}

	protected void fireOperationFailed(Throwable caught, String failure,
			String failureDetails) {
		for (OperationProgressListener listener : listeners)
			listener.operationFailed(caught, failure, failureDetails);
	}

	/**
	 * Add a new {@link OperationProgressListener} to this
	 * {@link OperationProgressUpdater}.
	 * 
	 * @param listener
	 *            the listener to add.
	 */
	public void addListener(OperationProgressListener listener) {
		listeners.add(listener);
	}

	/**
	 * Removes the specified {@link OperationProgressListener} from this
	 * {@link OperationProgressUpdater}.
	 * 
	 * @param listener
	 *            the listener to remove.
	 */
	public void removeListener(OperationProgressListener listener) {
		listeners.remove(listener);
	}
}
